@@ -72,12 +72,12 @@ orderly_test_start <- function(name, parameters = NULL, envir = parent.frame(),
            "directory to that path.  In order to continue testing your",
            "report interactively, please run",
            "",
-           sprintf('    setwd("%s")', info$workdir),
+           sprintf('    setwd("%s")', clean_path(info$workdir)),
            "",
            "you will be responsible for getting back to your previous working",
            "directory after this, which you can do with",
            "",
-           sprintf('    setwd("%s")', info$owd),
+           sprintf('    setwd("%s")', clean_path(info$owd)),
            "",
            "Please see the documentation ?orderly::orderly_test_start for",
            "more details")
